Sorted vectors of types implementing PartialOrd.
It is a runtime panic if an incomparable element is compared.
Structs
- Reverse sorted set
- Reverse sorted vector
- Forward sorted set
- Forward sorted vector
Sorted vectors of types implementing PartialOrd.
It is a runtime panic if an incomparable element is compared.