[−][src]Struct sorted_vec::ReverseSortedSet
Reverse sorted set
Implementations
impl<T: Ord> ReverseSortedSet<T>[src]
pub fn new() -> Self[src]
pub fn with_capacity(capacity: usize) -> Self[src]
pub fn from_unsorted(vec: Vec<T>) -> Self[src]
Uses sort_unstable() to sort in place and dedup() to remove
duplicates.
pub fn insert(&mut self, element: T) -> usize[src]
Insert an element into sorted position, returning the order index at which it was placed.
pub fn find_or_insert(&mut self, element: T) -> Result<usize, usize>[src]
Find the element and return the index with Ok, otherwise insert the
element and return the new element index with Err.
pub fn remove_item(&mut self, item: &T) -> Option<T>[src]
pub fn remove_index(&mut self, index: usize) -> T[src]
Panics if index is out of bounds
pub fn pop(&mut self) -> Option<T>[src]
pub fn clear(&mut self)[src]
pub fn drain<R>(&mut self, range: R) -> Drain<'_, T> where
R: RangeBounds<usize>, [src]
R: RangeBounds<usize>,
pub fn retain<F>(&mut self, f: F) where
F: FnMut(&T) -> bool, [src]
F: FnMut(&T) -> bool,
pub fn into_vec(self) -> Vec<T>[src]
NOTE: to_vec() is a slice method that is accessible through deref, use this instead to avoid cloning
pub fn mutate_vec<F, O>(&mut self, f: F) -> O where
F: FnOnce(&mut Vec<T>) -> O, [src]
F: FnOnce(&mut Vec<T>) -> O,
Apply a closure mutating the sorted vector and use sort_unstable()
to re-sort the mutated vector and dedup() to remove any duplicate
values
Methods from Deref<Target = ReverseSortedVec<T>>